import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AppsyncDatasourceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#api_id AppsyncDatasource#api_id}.
     *
     * @stability stable
     */
    readonly apiId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#description AppsyncDatasource#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#name AppsyncDatasource#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#service_role_arn AppsyncDatasource#service_role_arn}.
     *
     * @stability stable
     */
    readonly serviceRoleArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#type AppsyncDatasource#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * dynamodb_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#dynamodb_config AppsyncDatasource#dynamodb_config}
     *
     * @stability stable
     */
    readonly dynamodbConfig?: AppsyncDatasourceDynamodbConfig[];
    /**
     * elasticsearch_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#elasticsearch_config AppsyncDatasource#elasticsearch_config}
     *
     * @stability stable
     */
    readonly elasticsearchConfig?: AppsyncDatasourceElasticsearchConfig[];
    /**
     * http_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#http_config AppsyncDatasource#http_config}
     *
     * @stability stable
     */
    readonly httpConfig?: AppsyncDatasourceHttpConfig[];
    /**
     * lambda_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#lambda_config AppsyncDatasource#lambda_config}
     *
     * @stability stable
     */
    readonly lambdaConfig?: AppsyncDatasourceLambdaConfig[];
}
/**
 * @stability stable
 */
export interface AppsyncDatasourceDynamodbConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#region AppsyncDatasource#region}.
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#table_name AppsyncDatasource#table_name}.
     *
     * @stability stable
     */
    readonly tableName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#use_caller_credentials AppsyncDatasource#use_caller_credentials}.
     *
     * @stability stable
     */
    readonly useCallerCredentials?: boolean;
}
/**
 * @stability stable
 */
export interface AppsyncDatasourceElasticsearchConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#endpoint AppsyncDatasource#endpoint}.
     *
     * @stability stable
     */
    readonly endpoint: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#region AppsyncDatasource#region}.
     *
     * @stability stable
     */
    readonly region?: string;
}
/**
 * @stability stable
 */
export interface AppsyncDatasourceHttpConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#endpoint AppsyncDatasource#endpoint}.
     *
     * @stability stable
     */
    readonly endpoint: string;
}
/**
 * @stability stable
 */
export interface AppsyncDatasourceLambdaConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#function_arn AppsyncDatasource#function_arn}.
     *
     * @stability stable
     */
    readonly functionArn: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html aws_appsync_datasource}.
 *
 * @stability stable
 */
export declare class AppsyncDatasource extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html aws_appsync_datasource} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AppsyncDatasourceConfig);
    private _apiId;
    /**
     * @stability stable
     */
    get apiId(): string;
    /**
     * @stability stable
     */
    set apiId(value: string);
    /**
     * @stability stable
     */
    get apiIdInput(): string;
    /**
     * @stability stable
     */
    get arn(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _serviceRoleArn?;
    /**
     * @stability stable
     */
    get serviceRoleArn(): string;
    /**
     * @stability stable
     */
    set serviceRoleArn(value: string);
    /**
     * @stability stable
     */
    resetServiceRoleArn(): void;
    /**
     * @stability stable
     */
    get serviceRoleArnInput(): string | undefined;
    private _type;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string;
    private _dynamodbConfig?;
    /**
     * @stability stable
     */
    get dynamodbConfig(): AppsyncDatasourceDynamodbConfig[];
    /**
     * @stability stable
     */
    set dynamodbConfig(value: AppsyncDatasourceDynamodbConfig[]);
    /**
     * @stability stable
     */
    resetDynamodbConfig(): void;
    /**
     * @stability stable
     */
    get dynamodbConfigInput(): AppsyncDatasourceDynamodbConfig[] | undefined;
    private _elasticsearchConfig?;
    /**
     * @stability stable
     */
    get elasticsearchConfig(): AppsyncDatasourceElasticsearchConfig[];
    /**
     * @stability stable
     */
    set elasticsearchConfig(value: AppsyncDatasourceElasticsearchConfig[]);
    /**
     * @stability stable
     */
    resetElasticsearchConfig(): void;
    /**
     * @stability stable
     */
    get elasticsearchConfigInput(): AppsyncDatasourceElasticsearchConfig[] | undefined;
    private _httpConfig?;
    /**
     * @stability stable
     */
    get httpConfig(): AppsyncDatasourceHttpConfig[];
    /**
     * @stability stable
     */
    set httpConfig(value: AppsyncDatasourceHttpConfig[]);
    /**
     * @stability stable
     */
    resetHttpConfig(): void;
    /**
     * @stability stable
     */
    get httpConfigInput(): AppsyncDatasourceHttpConfig[] | undefined;
    private _lambdaConfig?;
    /**
     * @stability stable
     */
    get lambdaConfig(): AppsyncDatasourceLambdaConfig[];
    /**
     * @stability stable
     */
    set lambdaConfig(value: AppsyncDatasourceLambdaConfig[]);
    /**
     * @stability stable
     */
    resetLambdaConfig(): void;
    /**
     * @stability stable
     */
    get lambdaConfigInput(): AppsyncDatasourceLambdaConfig[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
